@@ -20,13 +20,14 @@
 
 #include <QObject>
 #include <QTime>
+#include <QUrl>
 
 class Utils : public QObject
 {
     Q_OBJECT
 public:
     explicit Utils(QObject* parent = 0);
-    Q_INVOKABLE QString findImage(QString name);
+    Q_INVOKABLE QUrl findImage(QString name);
     Q_INVOKABLE int getMinutesOfQTime(const QTime& time);
     Q_INVOKABLE int getSecondsOfQTime(const QTime& time);
     Q_INVOKABLE QString uuid();
